@@ -210,6 +210,18 @@ SPACES_SEARCH = Endpoint(
     LIMIT_APP_GET=300,
 )
 
+LIST_BY_ID = Endpoint(
+    resource="/lists/:id",
+    regex=re.compile(r"/lists/\d+"),
+    LIMIT_APP_GET=75,
+    LIMIT_USER_GET=75,
+)
+LISTS_BY_USER = Endpoint(
+    resource="/users/:id/owned_lists",
+    regex=re.compile(r"/users/\d+/owned_lists"),
+    LIMIT_APP_GET=15,
+    LIMIT_USER_GET=15,
+)
 LISTS_MANAGE = Endpoint(
     resource="/lists",
     regex=re.compile(r"/lists"),
@@ -221,6 +233,24 @@ LISTS_MANAGE_BY_ID = Endpoint(
     LIMIT_USER_PUT=300,
     LIMIT_USER_DELETE=300,
 )
+LIST_TWEETS = Endpoint(
+    resource="/lists/:id/tweets",
+    regex=re.compile(r"/lists/\d+/tweets"),
+    LIMIT_APP_GET=900,
+    LIMIT_USER_GET=900,
+)
+LIST_MEMBERS = Endpoint(
+    resource="/lists/:id/members",
+    regex=re.compile(r"/lists/\d+/members"),
+    LIMIT_APP_GET=900,
+    LIMIT_USER_GET=900,
+)
+LISTS_MEMBERSHIPS_BY_USER = Endpoint(
+    resource="/users/:id/list_memberships",
+    regex=re.compile(r"/users/\d+/list_memberships"),
+    LIMIT_APP_GET=75,
+    LIMIT_USER_GET=75,
+)
 LISTS_MANAGE_MEMBERS = Endpoint(
     resource="/lists/members",
     regex=re.compile(r"/lists/members"),
@@ -231,10 +261,18 @@ LISTS_MANAGE_MEMBERS_BY_ID = Endpoint(
     regex=re.compile(r"/lists/\w+/members/\d+"),
     LIMIT_USER_DELETE=300,
 )
+LISTS_MANAGE_FOLLOWERS = Endpoint(
+    resource="/lists/followers",
+    regex=re.compile(r"/lists/followers"),
+    LIMIT_USER_GET=180,
+    LIMIT_APP_GET=180,
+)
 USER_FOLLOW_LISTS = Endpoint(
     resource="/users/:id/followed_lists",
     regex=re.compile(r"/users/\d+/followed_lists"),
     LIMIT_USER_POST=50,
+    LIMIT_USER_GET=15,
+    LIMIT_APP_GET=15,
 )
 USER_FOLLOW_LISTS_BY_ID = Endpoint(
     resource="/users/:id/followed_lists/:list_id",
@@ -244,6 +282,7 @@ USER_FOLLOW_LISTS_BY_ID = Endpoint(
 USER_PINNED_LISTS = Endpoint(
     resource="/users/:id/pinned_lists",
     regex=re.compile(r"/users/\d+/pinned_lists"),
+    LIMIT_USER_GET=15,
     LIMIT_USER_POST=50,
 )
 USER_PINNED_LISTS_BY_ID = Endpoint(
@@ -295,10 +334,16 @@ PATH_VAR_ENDPOINTS = [
     SPACES_BY_IDS,
     SPACES_BY_CREATORS,
     SPACES_SEARCH,
+    LIST_BY_ID,
+    LISTS_BY_USER,
     LISTS_MANAGE,
     LISTS_MANAGE_BY_ID,
+    LIST_TWEETS,
+    LIST_MEMBERS,
+    LISTS_MEMBERSHIPS_BY_USER,
     LISTS_MANAGE_MEMBERS,
     LISTS_MANAGE_MEMBERS_BY_ID,
+    LISTS_MANAGE_FOLLOWERS,
     USER_FOLLOW_LISTS,
     USER_FOLLOW_LISTS_BY_ID,
     USER_PINNED_LISTS,
